@@ -1,5 +1,5 @@
 
-# $Id: FR.pm,v 2.102 2010-03-31 03:37:05 Martin Exp $
+# $Id: FR.pm,v 2.103 2013-03-03 15:03:57 Martin Exp $
 
 =head1 NAME
 
@@ -32,34 +32,28 @@ use warnings;
 use Carp;
 use base 'WWW::Search::Ebay';
 our
-$VERSION = do { my @r = (q$Revision: 2.102 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 2.103 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 
 sub _native_setup_search
   {
   my ($self, $native_query, $rhOptsArg) = @_;
-  $rhOptsArg ||= {};
-  unless (ref($rhOptsArg) eq 'HASH')
-    {
-    carp " --- second argument to _native_setup_search should be hashref, not arrayref";
-    return undef;
-    } # unless
-  $rhOptsArg->{search_host} = 'http://search.ebay.fr';
+  $self->{search_host} = 'http://www.ebay.fr';
   return $self->SUPER::_native_setup_search($native_query, $rhOptsArg);
   } # _native_setup_search
 
 # This is what we look_down for to find the HTML element that contains
 # the result count:
-sub _result_count_element_specs_USE_DEFAULT
+sub _result_count_element_specs
   {
   return (
-          '_tag' => 'p',
-          id => 'count'
+          '_tag' => 'span',
+          class => 'smuy'
          );
   } # _result_count_element_specs
 
 sub _result_count_pattern
   {
-  return qr'(\d+)\s+(r[©é]+sultat|objet)s?\s+trouv';
+  return qr'(\d+)[ \t\040\240]*(r[©é]+sultat|objet)s?\s+trouv';
   } # _result_count_pattern
 
 
@@ -97,7 +91,7 @@ sub _columns
   {
   my $self = shift;
   # This is for FR:
-  return qw( paypal bids price shipping enddate );
+  return qw( paypal bids price repeat shipping enddate );
   } # _columns
 
 sub _process_date_abbrevs
